Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(675)

Unified Diff: components/sync/engine_impl/sync_cycle_event.h

Issue 2258873003: [Sync] Move sessions/ to engine/cycle/ and rename things to match. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Address comments. Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/sync/engine_impl/process_updates_util.cc ('k') | components/sync/engine_impl/sync_scheduler.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/sync/engine_impl/sync_cycle_event.h
diff --git a/components/sync/engine_impl/sync_cycle_event.h b/components/sync/engine_impl/sync_cycle_event.h
index 53b99b3c65f5acb382cb6edf3c0b3fcebf5def82..dd40caf645237d8ab41a24f6a68a6f2949b5867d 100644
--- a/components/sync/engine_impl/sync_cycle_event.h
+++ b/components/sync/engine_impl/sync_cycle_event.h
@@ -5,7 +5,7 @@
#ifndef COMPONENTS_SYNC_ENGINE_IMPL_SYNC_CYCLE_EVENT_H_
#define COMPONENTS_SYNC_ENGINE_IMPL_SYNC_CYCLE_EVENT_H_
-#include "components/sync/sessions/sync_session_snapshot.h"
+#include "components/sync/engine/cycle/sync_cycle_snapshot.h"
namespace syncer {
@@ -29,8 +29,8 @@ struct SyncCycleEvent {
EventCause what_happened;
- // The last session used for syncing.
- sessions::SyncSessionSnapshot snapshot;
+ // The last cycle used for syncing.
+ SyncCycleSnapshot snapshot;
};
} // namespace syncer
« no previous file with comments | « components/sync/engine_impl/process_updates_util.cc ('k') | components/sync/engine_impl/sync_scheduler.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698